@@ -14,7 +14,7 @@ my @HEADERS = (
   qw/Proxy-Authenticate Proxy-Authorization Range Sec-WebSocket-Accept/,
   qw/Sec-WebSocket-Key Sec-WebSocket-Origin Sec-WebSocket-Protocol/,
   qw/Sec-WebSocket-Version Server Set-Cookie Status Trailer/,
-  qw/Transfer-Encoding Upgrade User-Agent WWW-Authenticate X-Forwarded-For/,
+  qw/Transfer-Encoding Upgrade User-Agent WWW-Authenticate/
 );
 {
   no strict 'refs';
@@ -88,14 +88,6 @@ sub header {
   return @$headers;
 }
 
-# DEPRECATED in Leaf Fluttering In Wind!
-sub is_done {
-  warn <<EOF;
-Mojo::Headers->is_done is DEPRECATED in favor of Mojo::Headers->is_finished!
-EOF
-  shift->is_finished;
-}
-
 sub is_finished { (shift->{state} || '') eq 'finished' }
 
 sub is_limit_exceeded { shift->{limit} }
@@ -195,6 +187,12 @@ sub to_string {
   return join "\x0d\x0a", @headers;
 }
 
+# DEPRECATED in Leaf Fluttering In Wind!
+sub x_forwarded_for {
+  warn "Mojo::Headers->x_forwarded_for is DEPRECATED!\n";
+  shift->header('X-Forwarded-For' => @_);
+}
+
 1;
 __END__
 
@@ -587,13 +585,6 @@ Shortcut for the C<User-Agent> header.
 
 Shortcut for the C<WWW-Authenticate> header.
 
-=head2 C<x_forwarded_for>
-
-  my $x_forwarded_for = $headers->x_forwarded_for;
-  $headers            = $headers->x_forwarded_for('127.0.0.1');
-
-Shortcut for the C<X-Forwarded-For> header.
-
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
