@@ -7,15 +7,7 @@ use Mojo::Util 'get_line';
 
 has [qw/code message/];
 
-my $START_LINE_RE = qr|
-  ^\s*
-  HTTP/(\d\.\d)   # Version
-  \s+
-  (\d\d\d)        # Code
-  \s*
-  ([\w\'\s]+)?    # Message (with "I'm a teapot" support)
-  $
-|x;
+my $START_LINE_RE = qr|^\s*HTTP/(\d\.\d)\s+(\d\d\d)\s*(.+)?$|x;
 
 # Umarked codes are from RFC 2616
 my %MESSAGES = (
