@@ -54,9 +54,9 @@ __DATA__
 use Mojo::Base -strict;
 
 use File::Basename 'dirname';
-use File::Spec;
+use File::Spec::Functions 'splitdir';
 
-push @INC, join('/', File::Spec->splitdir(dirname(__FILE__)), '..', 'lib');
+push @INC, join('/', splitdir(dirname(__FILE__)), '..', 'lib');
 
 # Check if Mojolicious is installed;
 die <<EOF unless eval 'use Mojolicious::Commands; 1';
